==> SampLin-1.3.1.tar.gz: SampLin-1.3.1/src/sqwt/dlg/GraphLayoutData.moc.cpp <==
/****************************************************************************
** GraphLayoutData meta object code from reading C++ file 'GraphLayoutData.h'
**
** Created: Mon Feb 22 21:44:59 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.11 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "GraphLayoutData.h"
#include <qmetaobject.h>


const char *GraphLayoutData::className() const
{
    return "GraphLayoutData";
}

QMetaObject *GraphLayoutData::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_GraphLayoutData(&GraphLayoutData::staticMetaObject);

#endif

void GraphLayoutData::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(QDialog::className(), "QDialog") != 0 )
	badSuperclassWarning("GraphLayoutData","QDialog");

#if QT_VERSION >= 200
    staticMetaObject();
}

void GraphLayoutData::staticMetaObject()
{
    if ( metaObj )
	return;
    QDialog::staticMetaObject();
#else

    QDialog::initMetaObject();
#endif

    typedef void(GraphLayoutData::*m1_t0)();
    m1_t0 v1_0 = &GraphLayoutData::selectFont;
    QMetaData *slot_tbl = new QMetaData[1];
    slot_tbl[0].name = "selectFont()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    metaObj = new QMetaObject( "GraphLayoutData", "QDialog",
	slot_tbl, 1,
	0, 0 );
}

==> SampLin-1.5.0.tar.gz: SampLin-1.5.0/src/sqwt/dlg/GraphLayoutData.moc.cpp <==
/****************************************************************************
** GraphLayoutData meta object code from reading C++ file 'GraphLayoutData.h'
**
** Created: Thu Sep 2 20:49:16 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.12 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "GraphLayoutData.h"
#include <qmetaobject.h>


const char *GraphLayoutData::className() const
{
    return "GraphLayoutData";
}

QMetaObject *GraphLayoutData::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_GraphLayoutData(&GraphLayoutData::staticMetaObject);

#endif

void GraphLayoutData::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(QWidget::className(), "QWidget") != 0 )
	badSuperclassWarning("GraphLayoutData","QWidget");

#if QT_VERSION >= 200
    staticMetaObject();
}

void GraphLayoutData::staticMetaObject()
{
    if ( metaObj )
	return;
    QWidget::staticMetaObject();
#else

    QWidget::initMetaObject();
#endif

    typedef void(GraphLayoutData::*m1_t0)();
    m1_t0 v1_0 = &GraphLayoutData::selectFont;
    QMetaData *slot_tbl = new QMetaData[1];
    slot_tbl[0].name = "selectFont()";
    slot_tbl[0].ptr = *((QMember*)&v1_0);
    metaObj = new QMetaObject( "GraphLayoutData", "QWidget",
	slot_tbl, 1,
	0, 0 );
}
